@@ -2,7 +2,6 @@
 #'
 #' @description Fits latent (or observed) multivariate (or univariate) mixed effects location scale models.
 #'
-#' @docType package
 #' @name LMMELSM-package
 #' @aliases LMMELSM
 #' @useDynLib LMMELSM, .registration = TRUE
@@ -12,5 +11,5 @@
 #'
 #' @references
 #' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.19.3. https://mc-stan.org
-#'
-NULL
+#' @keywords internal
+"_PACKAGE"
